@@ -19,8 +19,8 @@ fn main() {
     });
 
     let mut wv = fltk_webview::Webview::create(false, &mut wv_win);
-    wv.navigate("http://wikipedia.com");
+    wv.navigate("https://google.com");
     
     // the webview handles the main loop
-    _app.run().unwrap();
+    wv.run();
 }
